@@ -1,7 +1,7 @@
 c { dg-do run }
       DIMENSION A(-5:5)
-      INTEGER*1 IM5, IZ, IP5
-      INTEGER*2 IM1, IP1
+      INTEGER(kind=1) IM5, IZ, IP5
+      INTEGER(kind=2) IM1, IP1
       PARAMETER (IM5=-5, IM1=-1, IZ=0, IP1=1, IP5=5)
       DATA A(IM5) /-5./, A(IM1) /-1./
       DATA A(IZ)  /0./
